'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.types = exports.actions = exports.removeNotification = exports.updateNotification = exports.addNotification = undefined;

var _handleActions;

var _reduxActions = require('redux-actions');

var _helpers = require('../helpers');

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

// An array to store notifications object
var INITIAL_DATA = [];
// Action types
var ADD_NOTIFICATION = 'ADD_NOTIFICATION';
var UPDATE_NOTIFICATION = 'UPDATE_NOTIFICATION';
var REMOVE_NOTIFICATION = 'REMOVE_NOTIFICATION';

/**
 * Add a notification (thunk action creator)
 *
 * We use a thunk here to create an ADD_NOTIFICATION action
 * and only return the notification object.
 * @param {Object} notification
 * @returns {Object} notification
 */
var addNotification = exports.addNotification = function addNotification(notification) {
  return function (dispatch) {
    notification.id = new Date().getTime();
    notification = (0, _helpers.treatNotification)(notification);
    dispatch(_addNotification(notification));
    return notification;
  };
};

// Add a notification (action creator)
var _addNotification = (0, _reduxActions.createAction)(ADD_NOTIFICATION, function (notification) {
  return notification;
});

// Update a notification (action creator)
var updateNotification = exports.updateNotification = (0, _reduxActions.createAction)(UPDATE_NOTIFICATION, function (notification) {
  if (!notification.id) {
    throw new Error('A notification must have an `id` property to be updated');
  }
  return (0, _helpers.treatNotification)(notification);
});

// Remove a notification (action creator)
var removeNotification = exports.removeNotification = (0, _reduxActions.createAction)(REMOVE_NOTIFICATION, function (id) {
  return id;
});

// Action creators
var actions = exports.actions = {
  addNotification: addNotification,
  updateNotification: updateNotification,
  removeNotification: removeNotification
};

// Actions types
var types = exports.types = {
  ADD_NOTIFICATION: ADD_NOTIFICATION,
  UPDATE_NOTIFICATION: UPDATE_NOTIFICATION,
  REMOVE_NOTIFICATION: REMOVE_NOTIFICATION
};

// Reducers
exports.default = (0, _reduxActions.handleActions)((_handleActions = {}, _defineProperty(_handleActions, ADD_NOTIFICATION, function (state, _ref) {
  var payload = _ref.payload;

  return [].concat(_toConsumableArray(state), [payload]);
}), _defineProperty(_handleActions, UPDATE_NOTIFICATION, function (state, _ref2) {
  var payload = _ref2.payload;

  // get index of the notification
  var index = state.findIndex(function (notification) {
    return notification.id === payload.id;
  });
  // replace the old notification by the new one
  state[index] = Object.assign({}, payload);
  return [].concat(_toConsumableArray(state));
}), _defineProperty(_handleActions, REMOVE_NOTIFICATION, function (state, _ref3) {
  var payload = _ref3.payload;

  return state.filter(function (notification) {
    return notification.id !== payload;
  });
}), _handleActions), INITIAL_DATA);